#-*- coding:utf-8 -*-

#    Gedit but_active plugin version 3.1.0
#    Copyright © 2011-2013 sasakima-nao <sasakimanao@gmail.com>
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    2013.11.03 Version 3.1.0
#    Support Gedit 3.8 (Python3)
#    Remove Old Code
#
#    2012.08.23 Version 3.0.1
#    Move Menu : Notebook Popup to Documents Menu
#    ( Missing NotebookPopupMenu )
#    Keyboard ShortCut <Control><Shift><Alt>W
#
#    2011.06.04 Version 3.0.0

from gi.repository import GObject, Gedit, Gtk

ui_str3 = """<ui>
    <menubar name="MenuBar">
        <menu name="DocumentsMenu" action="Documents">
            <placeholder name="DocumentsOps_1">
                <menuitem name="but_active" action="but_active"/>
            </placeholder>
        </menu>
    </menubar>
</ui>
"""

class ButActivePlugin(GObject.Object, Gedit.WindowActivatable):
    __gtype_name__ = "ButActivePlugin"
    window = GObject.property(type=Gedit.Window)
    def __init__(self):
        GObject.Object.__init__(self)

    def do_activate(self):
        self.tab_list = []
        # GtkUIManager を得る
        manager = self.window.get_ui_manager()
        # GtkActionGroup を新規で作成
        self._action_group = Gtk.ActionGroup("but_activeActions")
        # GtkActionEntry を作成
        # name, stock_id, label, accelerator, tooltip, callback
        actions = [("but_active", None, "アクティブ以外全部閉じる", "<Control><Shift><Alt>W",
                    "アクティブなタブ以外全部閉じる", self.on_but_active_activate)]
        # GtkActionGroup に挿入
        self._action_group.add_actions(actions)
        # GtkUIManager に追加
        manager.insert_action_group(self._action_group, -1)
        self._ui_id = manager.add_ui_from_string(ui_str3)
        # window のシグナル接続
        self.id1 = self.window.connect("tab-added", self.on_tab_added)
        self.id2 = self.window.connect("tab-removed", self.on_tab_removed)

    def do_deactivate(self):
        manager = self.window.get_ui_manager()
        manager.remove_ui(self._ui_id)
        manager.remove_action_group(self._action_group)
        manager.ensure_update()
        # シグナルの切断を忘れずに
        self.window.disconnect(self.id1)
        self.window.disconnect(self.id2)

    def do_update_state(self):
        pass

    def on_tab_added(self, window, tab):
        self.tab_list.append(tab)

    def on_tab_removed(self, window, tab):
        self.tab_list.remove(tab)

    def on_but_active_activate(self, action, data=None):
        ac = self.window.get_active_tab()
        # removed に左右されるのでコピーしてからループ
        copy_list = self.tab_list[:]
        for tab in copy_list:
            if tab != ac:
                self.window.close_tab(tab)
