#-*- coding:utf-8 -*-

#    Gedit html_escape plugin version 3.1.0
#    Copyright © 2011-2013 sasakima-nao <sasakimanao@gmail.com>
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    2013.11.03 Version 3.1.0
#    Support Gedit 3.8 (Python3)
#
#    2011.06.04 Version 3.0.0

from gi.repository import GObject, Gedit, Gtk

ui_str = """<ui>
    <menubar name="MenuBar">
        <menu name="EditMenu" action="Edit">
            <placeholder name="EditOps_3">
                <menuitem name="EscHtml" action="EscHtml"/>
            </placeholder>
        </menu>
    </menubar>
</ui>
"""

class HtmlEscapePlugin(GObject.Object, Gedit.WindowActivatable):
    __gtype_name__ = "HtmlEscapePlugin"
    window = GObject.property(type=Gedit.Window)
    def __init__(self):
        GObject.Object.__init__(self)

    def do_activate(self):
        # Get GtkUIManager
        manager = self.window.get_ui_manager()
        # Create GtkActionGroup
        self._action_group = Gtk.ActionGroup("EscHtmlPluginActions")
        # GtkActionEntry(name, stock_id, label, accelerator, tooltip, callback)
        actions = [("EscHtml", None, "HTML エスケイプ", "<Control><Shift>E", "<>& をエンティティーに変換", self.on_esc_html_activate)]
        # Add GtkActionGroup
        self._action_group.add_actions(actions)
        # Insert GtkUIManager
        manager.insert_action_group(self._action_group, -1)
        self._ui_id = manager.add_ui_from_string(ui_str)

    def do_deactivate(self):
        manager = self.window.get_ui_manager()
        manager.remove_ui(self._ui_id)
        manager.remove_action_group(self._action_group)
        manager.ensure_update()


    def do_update_state(self):
        self._action_group.set_sensitive(self.window.get_active_document() != None)

    def on_esc_html_activate(self, action, data=None):
        view = self.window.get_active_view()
        buf = view.get_buffer()
        try:
            begin, end = buf.get_selection_bounds()
        except:
            self.messagebox("変換したいテキストを選択してください")
            return
        text = begin.get_text(end)
        result = ""
        for s in text:
            if s == "<":
                s = "&lt;"
            elif s == ">":
                s = "&gt;"
            elif s == "&":
                s = "&amp;"
            result += s
        buf.delete_selection(True, True)
        buf.insert_at_cursor(result)

    def messagebox(self, text):
        dlg = Gtk.MessageDialog(
                self.window,
                Gtk.DialogFlags.MODAL,
                Gtk.MessageType.WARNING,
                Gtk.ButtonsType.OK,
                text)
        r = dlg.run()
        dlg.destroy()
